@@ -984,3 +984,105 @@
 #define GI_AVAILABLE_ENUMERATOR_IN_2_80
 #define GI_AVAILABLE_TYPE_IN_2_80
 #endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_82
+#define GI_DEPRECATED_IN_2_82 GI_DEPRECATED
+#define GI_DEPRECATED_IN_2_82_FOR(f) GI_DEPRECATED_FOR (f)
+#define GI_DEPRECATED_MACRO_IN_2_82 GLIB_DEPRECATED_MACRO
+#define GI_DEPRECATED_MACRO_IN_2_82_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GI_DEPRECATED_ENUMERATOR_IN_2_82 GLIB_DEPRECATED_ENUMERATOR
+#define GI_DEPRECATED_ENUMERATOR_IN_2_82_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GI_DEPRECATED_TYPE_IN_2_82 GLIB_DEPRECATED_TYPE
+#define GI_DEPRECATED_TYPE_IN_2_82_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GI_DEPRECATED_IN_2_82 _GI_EXTERN
+#define GI_DEPRECATED_IN_2_82_FOR(f) _GI_EXTERN
+#define GI_DEPRECATED_MACRO_IN_2_82
+#define GI_DEPRECATED_MACRO_IN_2_82_FOR(f)
+#define GI_DEPRECATED_ENUMERATOR_IN_2_82
+#define GI_DEPRECATED_ENUMERATOR_IN_2_82_FOR(f)
+#define GI_DEPRECATED_TYPE_IN_2_82
+#define GI_DEPRECATED_TYPE_IN_2_82_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_82
+#define GI_AVAILABLE_IN_2_82 GI_UNAVAILABLE (2, 82)
+#define GI_AVAILABLE_STATIC_INLINE_IN_2_82 GLIB_UNAVAILABLE_STATIC_INLINE (2, 82)
+#define GI_AVAILABLE_MACRO_IN_2_82 GLIB_UNAVAILABLE_MACRO (2, 82)
+#define GI_AVAILABLE_ENUMERATOR_IN_2_82 GLIB_UNAVAILABLE_ENUMERATOR (2, 82)
+#define GI_AVAILABLE_TYPE_IN_2_82 GLIB_UNAVAILABLE_TYPE (2, 82)
+#else
+#define GI_AVAILABLE_IN_2_82 _GI_EXTERN
+#define GI_AVAILABLE_STATIC_INLINE_IN_2_82
+#define GI_AVAILABLE_MACRO_IN_2_82
+#define GI_AVAILABLE_ENUMERATOR_IN_2_82
+#define GI_AVAILABLE_TYPE_IN_2_82
+#endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_84
+#define GI_DEPRECATED_IN_2_84 GI_DEPRECATED
+#define GI_DEPRECATED_IN_2_84_FOR(f) GI_DEPRECATED_FOR (f)
+#define GI_DEPRECATED_MACRO_IN_2_84 GLIB_DEPRECATED_MACRO
+#define GI_DEPRECATED_MACRO_IN_2_84_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GI_DEPRECATED_ENUMERATOR_IN_2_84 GLIB_DEPRECATED_ENUMERATOR
+#define GI_DEPRECATED_ENUMERATOR_IN_2_84_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GI_DEPRECATED_TYPE_IN_2_84 GLIB_DEPRECATED_TYPE
+#define GI_DEPRECATED_TYPE_IN_2_84_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GI_DEPRECATED_IN_2_84 _GI_EXTERN
+#define GI_DEPRECATED_IN_2_84_FOR(f) _GI_EXTERN
+#define GI_DEPRECATED_MACRO_IN_2_84
+#define GI_DEPRECATED_MACRO_IN_2_84_FOR(f)
+#define GI_DEPRECATED_ENUMERATOR_IN_2_84
+#define GI_DEPRECATED_ENUMERATOR_IN_2_84_FOR(f)
+#define GI_DEPRECATED_TYPE_IN_2_84
+#define GI_DEPRECATED_TYPE_IN_2_84_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_84
+#define GI_AVAILABLE_IN_2_84 GI_UNAVAILABLE (2, 84)
+#define GI_AVAILABLE_STATIC_INLINE_IN_2_84 GLIB_UNAVAILABLE_STATIC_INLINE (2, 84)
+#define GI_AVAILABLE_MACRO_IN_2_84 GLIB_UNAVAILABLE_MACRO (2, 84)
+#define GI_AVAILABLE_ENUMERATOR_IN_2_84 GLIB_UNAVAILABLE_ENUMERATOR (2, 84)
+#define GI_AVAILABLE_TYPE_IN_2_84 GLIB_UNAVAILABLE_TYPE (2, 84)
+#else
+#define GI_AVAILABLE_IN_2_84 _GI_EXTERN
+#define GI_AVAILABLE_STATIC_INLINE_IN_2_84
+#define GI_AVAILABLE_MACRO_IN_2_84
+#define GI_AVAILABLE_ENUMERATOR_IN_2_84
+#define GI_AVAILABLE_TYPE_IN_2_84
+#endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_86
+#define GI_DEPRECATED_IN_2_86 GI_DEPRECATED
+#define GI_DEPRECATED_IN_2_86_FOR(f) GI_DEPRECATED_FOR (f)
+#define GI_DEPRECATED_MACRO_IN_2_86 GLIB_DEPRECATED_MACRO
+#define GI_DEPRECATED_MACRO_IN_2_86_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GI_DEPRECATED_ENUMERATOR_IN_2_86 GLIB_DEPRECATED_ENUMERATOR
+#define GI_DEPRECATED_ENUMERATOR_IN_2_86_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GI_DEPRECATED_TYPE_IN_2_86 GLIB_DEPRECATED_TYPE
+#define GI_DEPRECATED_TYPE_IN_2_86_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GI_DEPRECATED_IN_2_86 _GI_EXTERN
+#define GI_DEPRECATED_IN_2_86_FOR(f) _GI_EXTERN
+#define GI_DEPRECATED_MACRO_IN_2_86
+#define GI_DEPRECATED_MACRO_IN_2_86_FOR(f)
+#define GI_DEPRECATED_ENUMERATOR_IN_2_86
+#define GI_DEPRECATED_ENUMERATOR_IN_2_86_FOR(f)
+#define GI_DEPRECATED_TYPE_IN_2_86
+#define GI_DEPRECATED_TYPE_IN_2_86_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_86
+#define GI_AVAILABLE_IN_2_86 GI_UNAVAILABLE (2, 86)
+#define GI_AVAILABLE_STATIC_INLINE_IN_2_86 GLIB_UNAVAILABLE_STATIC_INLINE (2, 86)
+#define GI_AVAILABLE_MACRO_IN_2_86 GLIB_UNAVAILABLE_MACRO (2, 86)
+#define GI_AVAILABLE_ENUMERATOR_IN_2_86 GLIB_UNAVAILABLE_ENUMERATOR (2, 86)
+#define GI_AVAILABLE_TYPE_IN_2_86 GLIB_UNAVAILABLE_TYPE (2, 86)
+#else
+#define GI_AVAILABLE_IN_2_86 _GI_EXTERN
+#define GI_AVAILABLE_STATIC_INLINE_IN_2_86
+#define GI_AVAILABLE_MACRO_IN_2_86
+#define GI_AVAILABLE_ENUMERATOR_IN_2_86
+#define GI_AVAILABLE_TYPE_IN_2_86
+#endif
